//
//  ProfileViewController.m
//  Background Changer
//
//  Created by Shaheen Ghiassy on 8/14/13.
//  Copyright (c) 2013 Shaheen Ghiassy. All rights reserved.
//

#import "ProfileNavController.h"
#import "ProfileViewController.h"
#import "ProfileEditViewController.h"
#import "AFJSONRequestOperation.h"
#import "UIImageView+AFNetworking.h"
#import "User.h"
#import "UserPhoto.h"

@interface ProfileViewController ()

@end

@implementation ProfileViewController

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
        self.title = @"Profile";
        self.view.backgroundColor = [UIColor whiteColor];
        self.tabBarItem.image = [UIImage imageNamed:@"profile.png"];

        //Set Model Data
        self.user = [[User alloc] initWithFirstName:@"Shaheen" lastName:@"Ghiassy" city:@"Mountain View" bio:@"Shaheen is da awesomest" photo:[[UserPhoto alloc] initWithImage:@"shaheen.jpg" thumbnail:@"shaheen.jpg"]];
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view
    self.locationField.delegate = self;
    
    //Register Notifcation Handler
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(displayUser)
                                                 name:@"UserModelLoaded"
                                               object:nil];
}

- (void)displayUser
{
    //Create ScrollView
    self.scrollView = [[UIScrollView alloc] initWithFrame:self.view.bounds];
    self.scrollView.autoresizingMask = UIViewAutoresizingFlexibleHeight;
    self.scrollView.contentSize = CGSizeMake(320, 480);
    [self.view addSubview:self.scrollView];
    
    //Create Profile Image
    UIButton *selfImage = [UIButton buttonWithType:UIButtonTypeCustom];
    [selfImage setFrame:CGRectMake(10, 10, 150, 100)];
    [selfImage setImage:[self.user.userPhoto getProfilePicture] forState:UIControlStateNormal];
    [selfImage setImage:[self.user.userPhoto getProfilePicture] forState:UIControlStateHighlighted];
    [selfImage addTarget:self action:@selector(profilePressed:) forControlEvents:UIControlEventTouchUpInside];
    [self.scrollView addSubview:selfImage];
    
    //Create Name Label
    UILabel *name = [[UILabel alloc] initWithFrame:CGRectMake(20, 140, 180, 40)];
    name.text = [self.user getFullName];
    [self.scrollView addSubview:name];
    
    //Create City Label
    self.cityLabel = [[UILabel alloc] initWithFrame:CGRectMake(20, 170, 280, 40)];
    self.cityLabel.text = self.user.city;
    [self.scrollView addSubview:self.cityLabel];
    
    //Create IP Label
    UILabel *ipLabel = [[UILabel alloc] initWithFrame:CGRectMake(20, 440, 280, 40)];
    ipLabel.text = [NSString stringWithFormat:@"You're IP Address: %@", self.user.ipAddress];
    [self.scrollView addSubview:ipLabel];
    
    //Create Bio Text Area
    UITextView *bio = [[UITextView alloc] initWithFrame:CGRectMake(12, 260, 200, 380)];
    bio.font = [UIFont fontWithName:@"Helvetica" size:15];
    bio.editable = NO;
    bio.text = self.user.bio;
    [self.scrollView addSubview:bio];
    
    //Create Edit Button & Insert into Menu Bar
    UIBarButtonItem *editButton = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemEdit target:self action:@selector(editButtonPressed)];
    self.navigationItem.rightBarButtonItem = editButton; //Insert into Menu Bar
    
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(updateData) name:@"shit" object:nil];
}

-(void) updateData
{
    self.cityLabel.text = self.user.city;
}

- (void)editButtonPressed
{
    ProfileEditViewController *profileEditView = [[ProfileEditViewController alloc] init];
    profileEditView.user = self.user;
    [self presentViewController:profileEditView animated:YES completion:nil];
}

- (void)profilePressed:(UIButton *)sender
{
    [[NSNotificationCenter defaultCenter] postNotificationName:@"profileButtonPressed" object:nil];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
